@@ -29,7 +29,7 @@ class Diff:
 
 class Item:
     """
-    Item is responsible for storing the normal behavior of a small part of the response and to check if there are any differences.
+    Item is responsible for storing the normal behavior of a small section of the response and to check if there are any differences.
     """
 
     Static = 1
@@ -62,7 +62,7 @@ class Item:
                 if "42" in line:
                     self.analyze_methods.add(100)
 
-            def custom_is_diff(self,opcode,line):
+            def custom_find_diffs(self,opcode,line):
                 out=[]
                 if 5 not in self.analyze_methods:
                     return out
@@ -101,7 +101,7 @@ class Item:
         self.analyze_methods = analyze_methods
         self.lock.release()
 
-    def custom_is_diff(self, opcode, line):
+    def custom_find_diffs(self, opcode, line):
         # TODO: make it easier to create custom functions
         """
         used for creating a custom diff function. E.g.:
@@ -111,7 +111,7 @@ class Item:
                 if "42" in line:
                     self.analyze_methods.add(5)
 
-            def custom_is_diff(self,opcode,line):
+            def custom_find_diffs(self,opcode,line):
                 out=[]
                 if 5 not in self.analyze_methods:
                     return out
@@ -122,11 +122,11 @@ class Item:
 
         return []
 
-    def is_diff(self, opcode, line):
+    def find_diffs(self, opcode, line):
         """
         checks if new line behaves different from calibrated behavior
         """
-        out = self.custom_is_diff(opcode, line)
+        out = self.custom_find_diffs(opcode, line)
         if len(self.analyze_methods) == 0:
             return out
         if len(self.lines) == 0:
@@ -173,11 +173,12 @@ class Blob:
         """
         items is a dict of all split bytes from the given line.
         appended_items are bytes that has been inserted after the first response was submitted.
-        previous_static_items is starting empty and will be populated if previous static items suddenly change in is_diff.
+        previous_static_items is starting empty and will be populated if previous static items suddenly change in find_diffs.
         """
+        self.reflections=set()
         self.lock = Lock()
         self.items = {}
-        self.compile = rb",|\.|\s|;"
+        self.compile = rb"(,|\.|\s|;)"
         self.appended_items = {}
         self.previous_static_items = {}
         self.original_lines = []
@@ -188,6 +189,7 @@ class Blob:
 
         self.original_lines = re.split(self.compiled, line)
 
+
     def custom_add(self, line):
         # TODO: make it easier to create custom functions
         """
@@ -195,15 +197,28 @@ class Blob:
         """
         return
 
-    def add_line(self, line):
+    def add_line(self, line,payload=None):
         """
         Takes bytes as input and splits it up in to multiple Items.
         """
+        if payload:
+            payload=payload.encode()
+
         self.lock.acquire()
         self.custom_add(line)
         if len(self.original_lines) == 0:
             self.compiled = re.compile(self.compile)
             self.original_lines = re.split(self.compiled, line)
+            if payload:
+                for c,i in enumerate(self.original_lines.copy()): # Copying so we can make modifications to the lines in the loop
+                    if payload in i:
+                        self.reflections.add(c)
+                        self.original_lines[c] = b"REFLECTION"
+
+                if self.reflections:
+                    self.original_lines = [i for i in self.original_lines if len(i) > 1 and i != b"REFLECTION"] # Reflections often include strings that are identical to strings just around the reflection point. These are often characters of low length such as spaces. These mess with the indexing of the reflection point.
+
+
             self.lock.release()
             return
 
@@ -211,7 +226,7 @@ class Blob:
 
         diff = opcodes(self.original_lines, lines)
 
-        for opcode, l1, l2, r1, r2 in diff:
+        for opcode,l1,l2,r1,r2 in diff:
             if opcode == "insert":
                 for j in range(r1, r2):
                     if self.appended_items.get(l1) is None:
@@ -222,7 +237,7 @@ class Blob:
                 for j in range(l1, l2):
                     if self.items.get(j) is None:
                         self.items[j] = Item(self.original_lines[j])
-                    self.items[j].add_line("")
+                    self.items[j].add_line(b"")
 
             elif opcode == "replace":
                 for l, r in zip(range(l1, l2), range(r1, r2)):
@@ -231,25 +246,29 @@ class Blob:
                     self.items[l].add_line(lines[r])
         self.lock.release()
 
-    def custom_is_diff(self, line):
+    def custom_find_diffs(self, line):
         # TODO: make it easier to create custom functions
         """
-        used for creating a custom is_diff function.
+        used for creating a custom find_diffs function.
         """
         return []
 
-    def is_diff(self, line):
+    def find_diffs(self, line):
         """
         Takes in bytes, checks if any Item has changed behavior.
         """
-        out = self.custom_is_diff(line)
+        out = self.custom_find_diffs(line)
+
 
         lines = re.split(self.compiled, line)
+        if self.reflections:
+            lines = [i for i in lines if len(i) > 1] # Reflections often include strings that are identical to strings just around the reflection point. These are often characters of low length such as spaces. These mess with the indexing of the reflection point.
         diff = opcodes(self.original_lines, lines)
 
-        for opcode, l1, l2, r1, r2 in diff:
-            if opcode == "delete":
-                for j in range(l1, l2):
+        for opcode,l1,l2,r1,r2 in diff:
+
+            if opcode == "delete": 
+                for j in range(l1, l2): 
                     if self.items.get(j) is None:
                         self.lock.acquire()
                         if self.previous_static_items.get(j) is None:
@@ -260,7 +279,7 @@ class Blob:
                         self.lock.release()
                         continue
 
-                    out.extend(self.items[j].is_diff(opcode, ""))
+                    out.extend(self.items[j].find_diffs(opcode, b""))
 
             elif opcode == "insert":
                 for j in range(r1, r2):
@@ -274,7 +293,7 @@ class Blob:
                         self.lock.release()
                         continue
 
-                    out.extend(self.appended_items[l1].is_diff(opcode, lines[j]))
+                    out.extend(self.appended_items[l1].find_diffs(opcode, lines[j]))
 
             elif opcode == "replace":
                 for l, r in zip(range(l1, l2), range(r1, r2)):
@@ -290,7 +309,7 @@ class Blob:
                         self.lock.release()
                         continue
 
-                    out.extend(self.items[l].is_diff(opcode, lines[r]))
+                    out.extend(self.items[l].find_diffs(opcode, lines[r]))
         return out
 
 
@@ -316,7 +335,7 @@ class ResponseTimeBlob(Blob):
             pass
         self.lock.release()
 
-    def is_diff(self, line):
+    def find_diffs(self, line):
         """
         checks if new line behaves different from calibrated behavior
         """
